KeyId

Struct KeyId 

pub struct KeyId<A: KeyAlgorithm, K: KeyName + ?Sized>(/* private fields */);
A key algorithm and key name delimited by a colon.

Examples of the use of this struct are DeviceKeyId, which identifies a Ed25519 or Curve25519 device key, and CrossSigningKeyId, which identifies a user’s cross signing key.

This format of identifier is often used in the signatures field of signed JSON where it is referred to as a “signing key identifier”.

This struct is rarely used directly - instead you should expect to use one of the type aliases that rely on it like CrossSigningKeyId or DeviceSigningKeyId.

Examples

To parse a colon-separated identifier:

use ruma_common::DeviceKeyId;

let k = DeviceKeyId::parse("ed25519:1").unwrap();
assert_eq!(k.algorithm().as_str(), "ed25519");
assert_eq!(k.key_name(), "1");

To construct a colon-separated identifier from its parts:

use ruma_common::{DeviceKeyAlgorithm, DeviceKeyId};

let k = DeviceKeyId::from_parts(DeviceKeyAlgorithm::Curve25519, "MYDEVICE".into());
assert_eq!(k.as_str(), "curve25519:MYDEVICE");

Implementations

Source

impl<A: KeyAlgorithm, K: KeyName + ?Sized> KeyId<A, K>

pub fn as_str(&self) -> &str

Extracts a string slice from this KeyId.

pub fn as_bytes(&self) -> &[u8]

Extracts a byte slice from this KeyId.

Source

impl<A: KeyAlgorithm, K: KeyName + ?Sized> KeyId<A, K>

pub fn parse(s: impl AsRef<str>) -> Result<OwnedKeyId<A, K>, IdParseError>

Try parsing a &str into an OwnedKeyId.

The same can also be done using FromStr, TryFrom or TryInto. This function is simply more constrained and thus useful in generic contexts.

Source

impl<A: KeyAlgorithm, K: KeyName + ?Sized> KeyId<A, K>

pub fn from_parts(algorithm: A, key_name: &K) -> OwnedKeyId<A, K>

Creates a new KeyId from an algorithm and key name.

pub fn algorithm(&self) -> A

Returns key algorithm of the key ID - the part that comes before the colon.

Example
use ruma_common::{DeviceKeyAlgorithm, DeviceKeyId};

let k = DeviceKeyId::parse("ed25519:1").unwrap();
assert_eq!(k.algorithm(), DeviceKeyAlgorithm::Ed25519);
pub fn key_name<'a>(&'a self) -> &'a K
where &'a K: TryFrom<&'a str>,

Returns the key name of the key ID - the part that comes after the colon.

Example
use ruma_common::{DeviceKeyId, device_id};

let k = DeviceKeyId::parse("ed25519:DEV1").unwrap();
assert_eq!(k.key_name(), device_id!("DEV1"));