OwnedKeyId

Struct OwnedKeyId 

pub struct OwnedKeyId<A: KeyAlgorithm, K: KeyName + ?Sized> { /* private fields */ }
Owned variant of KeyId

Inner representation

By default, this type uses a Box<str> internally. The inner representation can be selected at compile time by using one of the following supported values:

  • Arc – Use an Arc<str>.

The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting. This setting can be configured using the RUSTFLAGS environment variable at build time, like this:

RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""

Or in .cargo/config.toml:

# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]

# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]

This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at compile time, which has the benefit of not requiring to re-compile the whole dependency chain when the value is changed, like this:

RUMA_IDENTIFIERS_STORAGE="{value}"

Implementations

Source

impl<A: KeyAlgorithm, K: KeyName + ?Sized> OwnedKeyId<A, K>

pub fn zeroize(self)

Securely zero memory (aka zeroize) of OwnedKeyId.

This method zeroizes this type by writing zeros in its memory location before freeing it. It internally uses the zeroize crate. Note that this type doesn’t implement the zeroize::Zeroize trait because the Zeroize::zeroize method takes a &mut self, which means we could put this type into an inconsistent state if it is used after calling that method. Instead, this method takes ownership of the type, ensuring it’s impossible to misuse it.

Implementation details

If the ruma_identifiers_storage configuration is set to Arc, this type will be zeroized if and only if Arc::get_mut returns Some reference, i.e. if there is no other Arc or Weak pointers to this same location.

Methods from Deref<Target = KeyId<A, K>>

pub fn as_str(&self) -> &str

Extracts a string slice from this KeyId.

pub fn as_bytes(&self) -> &[u8]

Extracts a byte slice from this KeyId.

pub fn algorithm(&self) -> A

Returns key algorithm of the key ID - the part that comes before the colon.

Example
use ruma_common::{DeviceKeyAlgorithm, DeviceKeyId};

let k = DeviceKeyId::parse("ed25519:1").unwrap();
assert_eq!(k.algorithm(), DeviceKeyAlgorithm::Ed25519);
pub fn key_name<'a>(&'a self) -> &'a K
where &'a K: TryFrom<&'a str>,

Returns the key name of the key ID - the part that comes after the colon.

Example
use ruma_common::{DeviceKeyId, device_id};

let k = DeviceKeyId::parse("ed25519:DEV1").unwrap();
assert_eq!(k.key_name(), device_id!("DEV1"));