pub struct OwnedDeviceId { /* private fields */ }Expand description
Owned variant of DeviceId
Inner representation
By default, this type uses a Box<str> internally. The inner representation can be selected at
compile time by using one of the following supported values:
Arc– Use anArc<str>.
The selected value can be set by using the ruma_identifiers_storage compile-time cfg setting.
This setting can be configured using the RUSTFLAGS environment variable at build time, like this:
RUSTFLAGS="--cfg ruma_identifiers_storage=\"{value}\""Or in .cargo/config.toml:
# General setting for all targets, overridden by per-target `rustflags` setting if set.
[build]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]
# Per-target setting.
[target.<triple/cfg>]
rustflags = ["--cfg", "ruma_identifiers_storage=\"{value}\""]This setting can also be configured using the RUMA_IDENTIFIERS_STORAGE environment variable at
compile time, which has the benefit of not requiring to re-compile the whole dependency chain
when the value is changed, like this:
RUMA_IDENTIFIERS_STORAGE="{value}"Trait Implementations
Sourceimpl AsRef<[u8]> for OwnedDeviceId
impl AsRef<[u8]> for OwnedDeviceId
Sourceimpl AsRef<DeviceId> for OwnedDeviceId
impl AsRef<DeviceId> for OwnedDeviceId
Sourceimpl AsRef<str> for OwnedDeviceId
impl AsRef<str> for OwnedDeviceId
Sourceimpl Borrow<DeviceId> for OwnedDeviceId
impl Borrow<DeviceId> for OwnedDeviceId
Sourceimpl Clone for OwnedDeviceId
impl Clone for OwnedDeviceId
Sourceimpl Debug for OwnedDeviceId
impl Debug for OwnedDeviceId
Sourceimpl Deref for OwnedDeviceId
impl Deref for OwnedDeviceId
Sourceimpl<'de> Deserialize<'de> for OwnedDeviceId
impl<'de> Deserialize<'de> for OwnedDeviceId
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for OwnedDeviceId
impl Display for OwnedDeviceId
Sourceimpl From<&DeviceId> for OwnedDeviceId
impl From<&DeviceId> for OwnedDeviceId
Sourceimpl From<&str> for OwnedDeviceId
impl From<&str> for OwnedDeviceId
Sourceimpl From<OwnedDeviceId> for Box<str>
impl From<OwnedDeviceId> for Box<str>
Sourcefn from(id: OwnedDeviceId) -> Self
fn from(id: OwnedDeviceId) -> Self
Converts to this type from the input type.
Sourceimpl From<OwnedDeviceId> for DeviceIdOrAllDevices
impl From<OwnedDeviceId> for DeviceIdOrAllDevices
Sourcefn from(d: OwnedDeviceId) -> Self
fn from(d: OwnedDeviceId) -> Self
Converts to this type from the input type.
Sourceimpl From<OwnedDeviceId> for OwnedBase64PublicKeyOrDeviceId
impl From<OwnedDeviceId> for OwnedBase64PublicKeyOrDeviceId
Sourcefn from(value: OwnedDeviceId) -> Self
fn from(value: OwnedDeviceId) -> Self
Converts to this type from the input type.
Sourceimpl From<OwnedDeviceId> for String
impl From<OwnedDeviceId> for String
Sourcefn from(id: OwnedDeviceId) -> Self
fn from(id: OwnedDeviceId) -> Self
Converts to this type from the input type.
Sourceimpl From<String> for OwnedDeviceId
impl From<String> for OwnedDeviceId
Sourceimpl Hash for OwnedDeviceId
impl Hash for OwnedDeviceId
Sourceimpl KeyName for OwnedDeviceId
impl KeyName for OwnedDeviceId
Sourceimpl Ord for OwnedDeviceId
impl Ord for OwnedDeviceId
Sourceimpl PartialEq<&DeviceId> for OwnedDeviceId
impl PartialEq<&DeviceId> for OwnedDeviceId
Sourceimpl PartialEq<&str> for OwnedDeviceId
impl PartialEq<&str> for OwnedDeviceId
Sourceimpl PartialEq<DeviceId> for OwnedDeviceId
impl PartialEq<DeviceId> for OwnedDeviceId
Sourceimpl PartialEq<OwnedDeviceId> for &DeviceId
impl PartialEq<OwnedDeviceId> for &DeviceId
Sourceimpl PartialEq<OwnedDeviceId> for &str
impl PartialEq<OwnedDeviceId> for &str
Sourceimpl PartialEq<OwnedDeviceId> for DeviceId
impl PartialEq<OwnedDeviceId> for DeviceId
Sourceimpl PartialEq<OwnedDeviceId> for String
impl PartialEq<OwnedDeviceId> for String
Sourceimpl PartialEq<OwnedDeviceId> for str
impl PartialEq<OwnedDeviceId> for str
Sourceimpl PartialEq<String> for OwnedDeviceId
impl PartialEq<String> for OwnedDeviceId
Sourceimpl PartialEq<str> for OwnedDeviceId
impl PartialEq<str> for OwnedDeviceId
Sourceimpl PartialEq for OwnedDeviceId
impl PartialEq for OwnedDeviceId
Sourceimpl PartialOrd for OwnedDeviceId
impl PartialOrd for OwnedDeviceId
Sourceimpl Serialize for OwnedDeviceId
impl Serialize for OwnedDeviceId
impl Eq for OwnedDeviceId